@@ -1,7 +1,7 @@
 
 /*
  * Copyright (c) 1989, 1993
- *	The Regents of the University of California.  All rights reserved.
+ *    The Regents of the University of California.  All rights reserved.
  *
  * This code is derived from software contributed to Berkeley by
  * Guido van Rossum.
@@ -34,44 +34,53 @@
 #ifndef __BSD_GLOB_H__
 #define __BSD_GLOB_H__ 1
 
+struct stat;
 typedef struct {
     unsigned long gl_maxfiles;  /* Maximum number of results */
     int gl_maxdepth;            /* Maximum depth */
-    int gl_pathc;               /* Count of total paths so far. */
-    int gl_matchc;              /* Count of paths matching pattern. */
-    int gl_offs;                /* Reserved at beginning of gl_pathv. */
-    int gl_flags;               /* Copy of flags parameter to glob. */
-    char **gl_pathv;            /* List of paths matching pattern. */
-    /* Copy of errfunc parameter to glob. */
-    int (*gl_errfunc) (const char *, int);
+	int gl_pathc;		/* Count of total paths so far. */
+	int gl_matchc;		/* Count of paths matching pattern. */
+	int gl_offs;		/* Reserved at beginning of gl_pathv. */
+	int gl_flags;		/* Copy of flags parameter to glob. */
+	char **gl_pathv;	/* List of paths matching pattern. */
+	struct stat **gl_statv;	/* Stat entries corresponding to gl_pathv */
+				/* Copy of errfunc parameter to glob. */
+	int (*gl_errfunc)(const char *, int);
 
-    /*
-     * Alternate filesystem access methods for glob; replacement
-     * versions of closedir(3), readdir(3), opendir(3), stat(2)
-     * and lstat(2).
-     */
-    void (*gl_closedir) (void *);
-    struct dirent *(*gl_readdir) (void *);
-    void *(*gl_opendir) (const char *);
-    int (*gl_lstat) (const char *, struct stat *);
-    int (*gl_stat) (const char *, struct stat *);
+	/*
+	 * Alternate filesystem access methods for glob; replacement
+	 * versions of closedir(3), readdir(3), opendir(3), stat(2)
+	 * and lstat(2).
+	 */
+	void (*gl_closedir)(void *);
+	struct dirent *(*gl_readdir)(void *);	
+	void *(*gl_opendir)(const char *);
+	int (*gl_lstat)(const char *, struct stat *);
+	int (*gl_stat)(const char *, struct stat *);
 } glob_t;
 
-#define    GLOB_ERR    0x0004  /* Return on error. */
-#define    GLOB_NOCHECK    0x0010  /* Return pattern itself if nothing matches. */
-#define    GLOB_NOSORT    0x0020  /* Don't sort. */
-#define    GLOB_NOESCAPE    0x1000  /* Disable backslash escaping. */
+#define	GLOB_APPEND	0x0001	/* Append to output from previous call. */
+#define	GLOB_DOOFFS	0x0002	/* Use gl_offs. */
+#define	GLOB_ERR	0x0004	/* Return on error. */
+#define	GLOB_MARK	0x0008	/* Append / to matching directories. */
+#define	GLOB_NOCHECK	0x0010	/* Return pattern itself if nothing matches. */
+#define	GLOB_NOSORT	0x0020	/* Don't sort. */
+#define	GLOB_NOESCAPE	0x1000	/* Disable backslash escaping. */
 
-#define    GLOB_NOSPACE    (-1)    /* Malloc call failed. */
-#define    GLOB_ABORTED    (-2)    /* Unignored error. */
-#define    GLOB_NOMATCH    (-3)    /* Malloc call failed. */
-#define    GLOB_NOSYS    (-4)    /* Implementation does not support function. */
+#define	GLOB_NOSPACE	(-1)	/* Malloc call failed. */
+#define	GLOB_ABORTED	(-2)	/* Unignored error. */
+#define	GLOB_NOMATCH	(-3)	/* No match and GLOB_NOCHECK not set. */
+#define	GLOB_NOSYS	(-4)	/* Function not supported. */
 
-#define    GLOB_BRACE    0x0080  /* Expand braces ala csh. */
-#define    GLOB_MAGCHAR    0x0100  /* Pattern had globbing characters. */
-#define    GLOB_QUOTE    0       /* source compatibility */
-
-#define    GLOB_ABEND    GLOB_ABORTED    /* source compatibility */
+#define	GLOB_ALTDIRFUNC	0x0040	/* Use alternately specified directory funcs. */
+#define	GLOB_BRACE	0x0080	/* Expand braces ala csh. */
+#define	GLOB_MAGCHAR	0x0100	/* Pattern had globbing characters. */
+#define	GLOB_NOMAGIC	0x0200	/* GLOB_NOCHECK without magic chars (csh). */
+#define	GLOB_QUOTE	0x0400	/* Quote special chars with \. */
+#define	GLOB_TILDE	0x0800	/* Expand tilde names from the passwd file. */
+#define GLOB_LIMIT	0x2000	/* Limit pattern match output */
+#define	GLOB_KEEPSTAT	0x4000	/* Retain stat data for paths in gl_statv. */
+#define GLOB_ABEND	GLOB_ABORTED /* backward compatibility */
 
 #ifdef DISABLE_GLOBBING
 # define glob(A, B, C, D) (GLOB_NOSYS)
